diff --git a/DiagnosticsPages.sln b/DiagnosticsPages.sln
index a4acc59b29..2cd1be0150 100644
--- a/DiagnosticsPages.sln
+++ b/DiagnosticsPages.sln
@@ -1,7 +1,7 @@
Microsoft Visual Studio Solution File, Format Version 12.00
# Visual Studio 14
-VisualStudioVersion = 14.0.21706.0
+VisualStudioVersion = 14.0.22013.1
MinimumVisualStudioVersion = 10.0.40219.1
Project("{2150E333-8FDC-42A3-9474-1A3956D46DE8}") = "src", "src", "{509A6F36-AD80-4A18-B5B1-717D38DFF29D}"
EndProject
@@ -15,6 +15,11 @@ Project("{8BB2217D-0F2D-49D1-97BC-3654ED321F3B}") = "ErrorPageSample", "samples\
EndProject
Project("{8BB2217D-0F2D-49D1-97BC-3654ED321F3B}") = "PageGenerator", "src\PageGenerator\PageGenerator.kproj", "{4D4A785A-ECB9-4916-A88F-0FD306EE3B74}"
EndProject
+Project("{2150E333-8FDC-42A3-9474-1A3956D46DE8}") = "Solution Items", "Solution Items", "{F0557697-8D86-4DF3-A385-B0BFA9596189}"
+ ProjectSection(SolutionItems) = preProject
+ global.json = global.json
+ EndProjectSection
+EndProject
Global
GlobalSection(SolutionConfigurationPlatforms) = preSolution
Debug|Any CPU = Debug|Any CPU
diff --git a/samples/ErrorPageSample/Startup.cs b/samples/ErrorPageSample/Startup.cs
index 74ad9f4e25..05b901b30d 100644
--- a/samples/ErrorPageSample/Startup.cs
+++ b/samples/ErrorPageSample/Startup.cs
@@ -5,7 +5,7 @@ namespace ErrorPageSample
{
public class Startup
{
- public void Configure(IBuilder app)
+ public void Configure(IApplicationBuilder app)
{
app.UseErrorPage();
app.Run(context =>
diff --git a/samples/WelcomePageSample/Startup.cs b/samples/WelcomePageSample/Startup.cs
index bbe72013d6..24bbfdeee4 100644
--- a/samples/WelcomePageSample/Startup.cs
+++ b/samples/WelcomePageSample/Startup.cs
@@ -5,7 +5,7 @@ namespace WelcomePageSample
{
public class Startup
{
- public void Configure(IBuilder app)
+ public void Configure(IApplicationBuilder app)
{
app.UseWelcomePage();
}
diff --git a/src/Microsoft.AspNet.Diagnostics/DiagnosticsPageExtensions.cs b/src/Microsoft.AspNet.Diagnostics/DiagnosticsPageExtensions.cs
index 15d303d4a5..6826247127 100644
--- a/src/Microsoft.AspNet.Diagnostics/DiagnosticsPageExtensions.cs
+++ b/src/Microsoft.AspNet.Diagnostics/DiagnosticsPageExtensions.cs
@@ -10,7 +10,7 @@ using Microsoft.AspNet.Diagnostics;
namespace Microsoft.AspNet.Builder
{
///
/// IBuilder extensions for the DiagnosticsPageMiddleware.
///
public static class DiagnosticsPageExtensions
{
@@ -20,7 +20,7 @@ namespace Microsoft.AspNet.Builder
///
///
///
- public static IBuilder UseDiagnosticsPage(this IBuilder builder, DiagnosticsPageOptions options)
+ public static IApplicationBuilder UseDiagnosticsPage(this IApplicationBuilder builder, DiagnosticsPageOptions options)
{
if (builder == null)
{
@@ -36,7 +36,7 @@ namespace Microsoft.AspNet.Builder
///
///
///
- public static IBuilder UseDiagnosticsPage(this IBuilder builder, PathString path)
+ public static IApplicationBuilder UseDiagnosticsPage(this IApplicationBuilder builder, PathString path)
{
return UseDiagnosticsPage(builder, new DiagnosticsPageOptions { Path = path });
}
@@ -46,7 +46,7 @@ namespace Microsoft.AspNet.Builder
///
///
///
- public static IBuilder UseDiagnosticsPage(this IBuilder builder)
+ public static IApplicationBuilder UseDiagnosticsPage(this IApplicationBuilder builder)
{
return UseDiagnosticsPage(builder, new DiagnosticsPageOptions());
}
@@ -10,7 +10,7 @@ using Microsoft.AspNet.Diagnostics;
{
///
- /// IBuilder extensions for the DiagnosticsPageMiddleware.
+ /// IApplicationBuilder extensions for the DiagnosticsPageMiddleware.
///
public static class DiagnosticsPageExtensions
diff --git a/src/Microsoft.AspNet.Diagnostics/ErrorPageExtensions.cs b/src/Microsoft.AspNet.Diagnostics/ErrorPageExtensions.cs
index 93aed93216..1bbf79e9b9 100644
--- a/src/Microsoft.AspNet.Diagnostics/ErrorPageExtensions.cs
+++ b/src/Microsoft.AspNet.Diagnostics/ErrorPageExtensions.cs
@@ -1,25 +1,23 @@
// Copyright (c) Microsoft Open Technologies, Inc. All rights reserved.
// Licensed under the Apache License, Version 2.0. See License.txt in the project root for license information.
-
using System;
using Microsoft.AspNet.Diagnostics;
-using Microsoft.AspNet.Http;
namespace Microsoft.AspNet.Builder
{
///
/// IBuilder extension methods for the ErrorPageMiddleware.
///
public static class ErrorPageExtensions
{
///
/// Captures synchronous and asynchronous exceptions from the pipeline and generates HTML error responses.
/// Full error details are only displayed by default if 'host.AppMode' is set to 'development' in the IBuilder.Properties.
///
///
///
- public static IBuilder UseErrorPage(this IBuilder builder)
+ public static IApplicationBuilder UseErrorPage(this IApplicationBuilder builder)
{
if (builder == null)
{
@@ -31,12 +29,12 @@ namespace Microsoft.AspNet.Builder
///
/// Captures synchronous and asynchronous exceptions from the pipeline and generates HTML error responses.
/// Full error details are only displayed by default if 'host.AppMode' is set to 'development' in the IBuilder.Properties.
///
///
///
///
- public static IBuilder UseErrorPage(this IBuilder builder, ErrorPageOptions options)
+ public static IApplicationBuilder UseErrorPage(this IApplicationBuilder builder, ErrorPageOptions options)
{
if (builder == null)
{
@@ -1,25 +1,23 @@
{
///
- /// IBuilder extension methods for the ErrorPageMiddleware.
+ /// IApplicationBuilder extension methods for the ErrorPageMiddleware.
///
public static class ErrorPageExtensions
@@ -1,25 +1,23 @@
///
/// Captures synchronous and asynchronous exceptions from the pipeline and generates HTML error responses.
- /// Full error details are only displayed by default if 'host.AppMode' is set to 'development' in the IBuilder.Properties.
+ /// Full error details are only displayed by default if 'host.AppMode' is set to 'development' in the IApplicationBuilder.Properties.
///
///
@@ -31,12 +29,12 @@ namespace Microsoft.AspNet.Builder
///
/// Captures synchronous and asynchronous exceptions from the pipeline and generates HTML error responses.
- /// Full error details are only displayed by default if 'host.AppMode' is set to 'development' in the IBuilder.Properties.
+ /// Full error details are only displayed by default if 'host.AppMode' is set to 'development' in the IApplicationBuilder.Properties.
///
///
diff --git a/src/Microsoft.AspNet.Diagnostics/WelcomePageExtensions.cs b/src/Microsoft.AspNet.Diagnostics/WelcomePageExtensions.cs
index 6918a35332..6ae1d3d46e 100644
--- a/src/Microsoft.AspNet.Diagnostics/WelcomePageExtensions.cs
+++ b/src/Microsoft.AspNet.Diagnostics/WelcomePageExtensions.cs
@@ -9,7 +9,7 @@ using Microsoft.AspNet.Diagnostics;
namespace Microsoft.AspNet.Builder
{
///
/// IBuilder extensions for the WelcomePageMiddleware.
///
public static class WelcomePageExtensions
{
@@ -19,7 +19,7 @@ namespace Microsoft.AspNet.Builder
///
///
///
- public static IBuilder UseWelcomePage(this IBuilder builder, WelcomePageOptions options)
+ public static IApplicationBuilder UseWelcomePage(this IApplicationBuilder builder, WelcomePageOptions options)
{
if (builder == null)
{
@@ -35,7 +35,7 @@ namespace Microsoft.AspNet.Builder
///
///
///
- public static IBuilder UseWelcomePage(this IBuilder builder, PathString path)
+ public static IApplicationBuilder UseWelcomePage(this IApplicationBuilder builder, PathString path)
{
return UseWelcomePage(builder, new WelcomePageOptions { Path = path });
}
@@ -46,7 +46,7 @@ namespace Microsoft.AspNet.Builder
///
///
///
- public static IBuilder UseWelcomePage(this IBuilder builder, string path)
+ public static IApplicationBuilder UseWelcomePage(this IApplicationBuilder builder, string path)
{
return UseWelcomePage(builder, new WelcomePageOptions { Path = new PathString(path) });
}
@@ -56,7 +56,7 @@ namespace Microsoft.AspNet.Builder
///
///
///
- public static IBuilder UseWelcomePage(this IBuilder builder)
+ public static IApplicationBuilder UseWelcomePage(this IApplicationBuilder builder)
{
return UseWelcomePage(builder, new WelcomePageOptions());
}
@@ -9,7 +9,7 @@ using Microsoft.AspNet.Diagnostics;
{
///
- /// IBuilder extensions for the WelcomePageMiddleware.
+ /// IApplicationBuilder extensions for the WelcomePageMiddleware.
///
public static class WelcomePageExtensions